@@ -120,6 +120,12 @@ def parse_args():
         type=int,
         default=0,
     )
+    parser.add_argument(
+        '--checkin-frequency-seconds',
+        help='Number of seconds to wait between worker check-ins',
+        type=int,
+        default=5,
+    )
     parser.add_argument(
         '--id',
         default='%s(%d)' % (socket.gethostname(), os.getpid()),
@@ -259,6 +265,7 @@ def main():
         args.exit_when_idle,
         args.exit_after_num_runs,
         args.idle_seconds,
+        args.checkin_frequency_seconds,
         bundle_service,
         args.shared_file_system,
         args.tag_exclusive,
