@@ -59,6 +59,11 @@ def main():
         default=1 * 60,
         type=int,
     )
+    parser.add_argument(
+        '--worker-checkin-frequency-seconds',
+        type=int,
+        help='If specified, the CodaLab worker will wait this many seconds between check-ins',
+    )
     parser.add_argument(
         '--worker-exit-after-num-runs',
         type=int,
